@@ -43,7 +43,7 @@ def projects_from_requirements(requirements):
             elif req.editable:
                 log.warning(
                     'Skipping {0}: editable projects unsupported'.format(req.name))
-            elif req.url and req.url.startswith('file:'):
+            elif req_has_file_link(req):
                 log.warning(
                     'Skipping {0}: file-specified projects unsupported'.format(req.name))
             else:
@@ -51,6 +51,16 @@ def projects_from_requirements(requirements):
     return valid_reqs
 
 
+def req_has_file_link(req):
+    url = getattr(req, 'url', None)
+    if url and url.lower().startswith('file:'):
+        return True
+    link = getattr(req, 'link', None)
+    if link and getattr(link, 'scheme', '') == 'file':
+        return True
+    return False
+
+
 def projects_from_metadata(metadata):
     """Extract the project dependencies from a metadata spec."""
     projects = []
@@ -97,7 +107,16 @@ def projects_from_cli(args):
 def message(blockers):
     """Create a sequence of key messages based on what is blocking."""
     if not blockers:
-        return ['You have 0 projects blocking you from using Python 3!']
+        encoding = getattr(sys.stdout, 'encoding', '')
+        if encoding:
+            encoding = encoding.lower()
+        if encoding == 'utf-8':
+            # party hat
+            flair = "\U0001F389  "
+        else:
+            flair = ''
+        return [flair +
+                'You have 0 projects blocking you from using Python 3!']
     flattened_blockers = set()
     for blocker_reasons in blockers:
         for blocker in blocker_reasons:
@@ -139,6 +158,9 @@ def pprint_blockers(blockers):
 
 def check(projects):
     """Check the specified projects for Python 3 compatibility."""
+    # Without this, the 'ciu' logger will emit nothing.
+    logging.basicConfig(format='[%(levelname)s] %(message)s')
+
     log = logging.getLogger('ciu')
     log.info('{0} top-level projects to check'.format(len(projects)))
     print('Finding and checking dependencies ...')
@@ -154,8 +176,6 @@ def check(projects):
 
 
 def main(args=sys.argv[1:]):
-    # Without this, the 'ciu' logger will emit nothing.
-    logging.basicConfig(format='[%(levelname)s] %(message)s')
     check(projects_from_cli(args))
 
 
